(created-on file)Returns the creation date of the file as an instant
Returns the creation date of the file as an instant
(cwd-path)(dir-exists? d)(exists? file)(ext file)(file->uri file)(file-uri? file-uri)(filename file)(mkdir path)(rmdir path)(size file)(subdir parent subname)Returns a File of a subdirectory validating it is a directory type and exists. Throws an anomly otherwise.
Returns a File of a subdirectory validating it is a directory type and exists. Throws an anomly otherwise.
(uri->file file-uri)Converts the file uri into an io/file. If it does not exist or the uri is not a file uri an anomly is thrown.
Converts the file uri into an io/file. If it does not exist or the uri is not a file uri an anomly is thrown.
(uri-exists? file-uri)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |